## cdist-type__ssh_authorized_key(7)

### Steven Armstrong

`<steven-cdist--@--armstrong.cc>`

## 1. NAME

cdist-type__ssh_authorized_key - manage a single ssh authorized key entry

## 2. DESCRIPTION

Manage a single authorized key entry in an authorized_key file. This type was created to be used by the __ssh_authorized_keys type.

## 3. REQUIRED PARAMETERS

file
  the authorized_keys file to which the given key should be added
key
  a string containing the ssh keytype, base 64 encoded key and optional trailing comment which shall be added to the given authorized_keys file.

## 4. OPTIONAL PARAMETERS

comment
  explicit comment instead of the one which may be trailing the given key
option
  an option to set for this authorized_key entry. Can be specified multiple times. See sshd(8) for available options.
state
  if the given keys should be present or absent, defaults to present.

## 5. EXAMPLES

    __ssh_authorized_key some-id \
       --file "/home/user/.ssh/autorized_keys" \
       --key "$(cat ~/.ssh/id_rsa.pub)"

    __ssh_authorized_key some-id \
       --file "/home/user/.ssh/autorized_keys" \
       --key "$(cat ~/.ssh/id_rsa.pub)" \
       --option 'command="/path/to/script"' \
       --option 'environment="FOO=bar"' \
       --comment 'one to rule them all'

## 6. SEE ALSO

- cdist-type(7)
- cdist__ssh_authorized_keys(7)
- sshd(8)

## 7. COPYING

Copyright (C) 2014 Steven Armstrong. Free use of this software is granted under the terms of the GNU General Public License version 3 (GPLv3).